package com.patzn.cloud.service.lims.hmhj.controller;

import com.patzn.cloud.service.hmhj.entity.ContractSample;
import com.patzn.cloud.service.hmhj.enums.ContractSampleStatusEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.plugins.Page;
import com.patzn.cloud.commons.api.RestConstants;
import com.patzn.cloud.commons.api.RestResult;
import com.patzn.cloud.commons.controller.ServiceController;
import com.patzn.cloud.service.lims.hmhj.service.IContractSampleService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.util.List;

/**
 * 合同物资 前端控制器
 *
 * @author wwd
 * @since 2021-02-01
 */
@Api(tags = "合同物资")
@RestController
@RequestMapping("/v1/contract_sample")
public class ContractSampleController extends ServiceController {

    @Autowired
    private IContractSampleService contractSampleService;

    @ApiOperation("分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page")
	public RestResult<Page<ContractSample>> getPage(ContractSample contractSample) {
        contractSample.setStatus(ContractSampleStatusEnum.DRAFT);
        return success(contractSampleService.page(getPage(), contractSample));
	}



    @ApiOperation("储运登记分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page_store_transport")
    public RestResult<Page<ContractSample>> getPageStoreTransport(ContractSample contractSample) {
        contractSample.setStatus(ContractSampleStatusEnum.STORE_TRANSPORT);
        return success(contractSampleService.page(getPage(), contractSample));
    }


    @ApiOperation("储运登记分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page_pro_tech_check")
    public RestResult<Page<ContractSample>> getPageProTechCheck(ContractSample contractSample) {
        contractSample.setStatus(ContractSampleStatusEnum.PRO_TEC_CHECK);
        return success(contractSampleService.page(getPage(), contractSample));
    }


    @ApiOperation("验收任务登记登记分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page_check_accept_reg")
    public RestResult<Page<ContractSample>> getPageCheckAcceptReg(ContractSample contractSample) {
        contractSample.setStatus(ContractSampleStatusEnum.CHECK_ACCEPT_REG);
        return success(contractSampleService.page(getPage(), contractSample));
    }



    @ApiOperation("验收组织分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page_check_accept_org")
    public RestResult<Page<ContractSample>> getPageCheckAcceptOrg(ContractSample contractSample) {
        contractSample.setStatus(ContractSampleStatusEnum.CHECK_ACCEPT_ORg);
        return success(contractSampleService.page(getPage(), contractSample));
    }




    @ApiOperation("根据ID查询列表分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page_by_ids")
    public RestResult<Page<ContractSample>> getPageByIds(@RequestParam("ids") Long [] ids) {
        return success(contractSampleService.pageByIds(getPage(), ids));
    }




    @ApiOperation("查询 id 信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataTypeClass = Long.class),
    })
    @GetMapping("/{id}")
    public RestResult<ContractSample> get(@PathVariable("id") Long id) {
        return success(contractSampleService.getById(id));
    }

    @ApiOperation("根据 id 修改信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataTypeClass = Long.class),
    })
    @PutMapping("/{id}")
	public RestResult<Boolean> edit(@PathVariable("id") Long id, ContractSample contractSample) {
        contractSample.setId(id);
        return success(contractSampleService.updateById(contractSample));
	}

    @ApiOperation("添加")
    @PostMapping("/")
	public RestResult<Boolean> add(ContractSample contractSample) {
        return success(contractSampleService.save(contractSample));
	}



    @ApiOperation("提交至储运登记")
    @PostMapping("/submit_to_store_transport")
    public RestResult<Boolean> submitToStoreTransport(@RequestParam("ids") Long [] ids) {
        return success(contractSampleService.submitToStoreTransport(ids,getAccount()));
    }



    @ApiOperation("提交至验收任务登记")
    @PostMapping("/submit_to_check_accept_reg")
    public RestResult<Boolean> submitToCheckAcceptReg(@RequestParam("ids") Long [] ids) {
        return success(contractSampleService.submitToCheckAcceptReg(ids,getAccount()));
    }



    @ApiOperation("验收任务登记提交至验收组织")
    @PostMapping("/submit_to_check_accept_org")
    public RestResult<Boolean> submitToCheckAcceptOrg(@RequestParam("ids") Long [] ids) {
        return success(contractSampleService.submitToCheckAcceptOrg(ids,getAccount()));
    }


    @ApiOperation("提交至生技部审核")
    @PostMapping("/submit_to_pro_tech_check")
    public RestResult<Boolean> submitToProTechCheck(@RequestParam("ids") Long [] ids) {
        return success(contractSampleService.submitToProTechCheck(ids,getAccount()));
    }


    @ApiOperation("生技部审核退回")
    @PostMapping("/back_pro_tech_check")
    public RestResult<Boolean> backProTechCheck(@RequestParam("ids") Long [] ids,@RequestParam("reason") String reason) {
        return success(contractSampleService.backProTechCheck(ids,reason,getAccount()));
    }



    @ApiOperation("根据 ids 删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids", value = "主键列表", required = true, paramType = "query", allowMultiple = true, dataTypeClass = Long.class),
    })
	@DeleteMapping("/")
	public RestResult<Boolean> delete(@RequestParam("ids") List<Long> ids) {
        return success(contractSampleService.removeByIds(ids));
	}
}
