package com.patzn.cloud.service.lims.hmhj.controller;

import com.patzn.cloud.service.hmhj.entity.EntrustSample;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.baomidou.mybatisplus.plugins.Page;
import com.patzn.cloud.commons.api.RestConstants;
import com.patzn.cloud.commons.api.RestResult;
import com.patzn.cloud.commons.controller.ServiceController;
import com.patzn.cloud.service.lims.hmhj.service.IEntrustSampleService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;

import java.util.List;

/**
 * 委托单样品 前端控制器
 *
 * @author wwd
 * @since 2021-02-01
 */
@Api(tags = "委托单样品")
@RestController
@RequestMapping("/v1/entrust_sample")
public class EntrustSampleController extends ServiceController {

    @Autowired
    private IEntrustSampleService entrustSampleService;

    @ApiOperation("分页列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = RestConstants.PAGE_PAGE, value = "请求数据的页码", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_ROWS, value = "每页条数", required = true, paramType = "query", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SIDX, value = "排序字段", paramType = "query", dataTypeClass = String.class),
            @ApiImplicitParam(name = RestConstants.PAGE_SORD, value = "排序方式", paramType = "query", dataTypeClass = String.class),
    })
    @PostMapping("/page")
	public RestResult<Page<EntrustSample>> getPage(EntrustSample entrustSample) {
        return success(entrustSampleService.page(getPage(), entrustSample));
	}

    @ApiOperation("查询 id 信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataTypeClass = Long.class),
    })
    @GetMapping("/{id}")
    public RestResult<EntrustSample> get(@PathVariable("id") Long id) {
        return success(entrustSampleService.getById(id));
    }

    @ApiOperation("根据 id 修改信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "id", value = "主键", required = true, paramType = "path", dataTypeClass = Long.class),
    })
    @PutMapping("/{id}")
	public RestResult<Boolean> edit(@PathVariable("id") Long id, EntrustSample entrustSample) {
        entrustSample.setId(id);
        return success(entrustSampleService.updateById(entrustSample));
	}

    @ApiOperation("添加")
    @PostMapping("/")
	public RestResult<Boolean> add(EntrustSample entrustSample) {
        return success(entrustSampleService.save(entrustSample));
	}

    @ApiOperation("根据 ids 删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "ids", value = "主键列表", required = true, paramType = "query", allowMultiple = true, dataTypeClass = Long.class),
    })
	@DeleteMapping("/")
	public RestResult<Boolean> delete(@RequestParam("ids") List<Long> ids) {
        return success(entrustSampleService.removeByIds(ids));
	}
}
