package com.patzn.cloud.service.lims.hmhj.service.impl;

import com.baomidou.mybatisplus.mapper.Condition;
import com.patzn.cloud.commons.api.RestAssert;
import com.patzn.cloud.commons.controller.Account;
import com.patzn.cloud.service.hmhj.entity.ContractSample;
import com.patzn.cloud.service.hmhj.enums.ContractSampleStatusEnum;
import com.patzn.cloud.service.lims.common.service.ILmsMsgService;
import com.patzn.cloud.service.lims.hmhj.mapper.ContractSampleMapper;
import com.patzn.cloud.service.lims.hmhj.service.IContractSampleRecordService;
import com.patzn.cloud.service.lims.hmhj.service.IContractSampleService;
import com.patzn.cloud.commons.service.impl.BaseServiceImpl;
import org.apache.commons.lang3.ArrayUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.mapper.EntityWrapper;
import com.baomidou.mybatisplus.mapper.Wrapper;
import com.baomidou.mybatisplus.plugins.Page;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 *  服务实现类
 *
 * @author wwd
 * @since 2021-02-01
 */
@Service
public class ContractSampleServiceImpl extends BaseServiceImpl<ContractSampleMapper, ContractSample> implements IContractSampleService {


    @Autowired
    private IContractSampleRecordService contractSampleRecordService;

    @Autowired
    private ILmsMsgService lmsMsgService;

    @Override
    public Page<ContractSample> page(Page<ContractSample> page, ContractSample contractSample) {
        Wrapper wrapper = new EntityWrapper<>(contractSample);

        return this.page(page, wrapper);
    }


    @Override
    public Page<ContractSample> pageByIds(Page<ContractSample> page, Long [] ids) {
        Wrapper wrapper = new EntityWrapper<>();
        wrapper.in("id",ids);
        return this.page(page, wrapper);
    }

    @Override
    public boolean removeByIds(List<Long> ids) {
        return baseMapper.deleteBatchIds(ids) > 0;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean submitToStoreTransport(Long[] ids, Account account) {
        RestAssert.fail(ArrayUtils.isEmpty(ids),"请选择要提交的合同！");
        ContractSample contractSample = new ContractSample();
        contractSample.setStatus(ContractSampleStatusEnum.STORE_TRANSPORT);
        contractSample.setProgress(ContractSampleStatusEnum.STORE_TRANSPORT);
        return super.update(contractSample,Condition.create().in("id",ids));
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean submitToProTechCheck(Long[] ids, Account account) {
        RestAssert.fail(ArrayUtils.isEmpty(ids),"请选择要提交的合同！");
        ContractSample contractSample = new ContractSample();
        contractSample.setStatus(ContractSampleStatusEnum.PRO_TEC_CHECK);
        contractSample.setProgress(ContractSampleStatusEnum.PRO_TEC_CHECK);
        return super.update(contractSample,Condition.create().in("id",ids));
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean backProTechCheck(Long[] ids, String reason, Account account) {
        RestAssert.fail(ArrayUtils.isEmpty(ids),"请选择要提交的合同！");
        RestAssert.fail(StringUtils.isBlank(reason),"请填写退回原因！");

        ContractSample contractSample = new ContractSample();
        contractSample.setStatus(ContractSampleStatusEnum.STORE_TRANSPORT);
        contractSample.setProgress(ContractSampleStatusEnum.BACK_PRO_TEC_CHECK);

        contractSampleRecordService.record(ids,ContractSampleStatusEnum.PRO_TEC_CHECK,ContractSampleStatusEnum.STORE_TRANSPORT,1,reason,account);
        lmsMsgService.sendMsg("/hmhj/contract_manage/storage_register","有合同从生技部退回，请及时处理","新的生技部退回任务！",account,null);
        return super.update(contractSample,Condition.create().in("id",ids));
    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean submitToCheckAcceptReg(Long[] ids, Account account) {
        RestAssert.fail(ArrayUtils.isEmpty(ids),"请选择要提交的合同！");
        ContractSample contractSample = new ContractSample();
        contractSample.setStatus(ContractSampleStatusEnum.CHECK_ACCEPT_REG);
        contractSample.setProgress(ContractSampleStatusEnum.CHECK_ACCEPT_REG);
        contractSampleRecordService.record(ids,ContractSampleStatusEnum.STORE_TRANSPORT,ContractSampleStatusEnum.CHECK_ACCEPT_REG,0,"提交至验收任务登记",account);
        lmsMsgService.sendMsg("/hmhj/accept_manage/accept_register","有合同从储运任务提交过来，请及时处理","新的验收任务登记任务！",account,null);
        return super.update(contractSample,Condition.create().in("id",ids));

    }


    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean submitToCheckAcceptOrg(Long[] ids, Account account) {
        RestAssert.fail(ArrayUtils.isEmpty(ids),"请选择要提交的合同！");
        ContractSample contractSample = new ContractSample();
        contractSample.setStatus(ContractSampleStatusEnum.CHECK_ACCEPT_ORg);
        contractSample.setProgress(ContractSampleStatusEnum.CHECK_ACCEPT_ORg);
        contractSampleRecordService.record(ids,ContractSampleStatusEnum.CHECK_ACCEPT_REG,ContractSampleStatusEnum.CHECK_ACCEPT_ORg,0,"验收任务登记提交至验收组织",account);
        lmsMsgService.sendMsg("/hmhj/accept_manage/accept_organization","验收任务由验收任务登记提交过来，请及时处理","新的验收组织任务！",account,null);
        return super.update(contractSample,Condition.create().in("id",ids));
    }




}
